@@ -38,7 +38,6 @@ def syscaller(print):
             print(line)
         p.wait()
         p.stdout.close()
-        if p.returncode:
-            logger.error("task failed")
+        return p.returncode
 
     return system
